@@ -1,7 +1,7 @@
 #![cfg_attr(not(feature = "std"), no_std)]
 #![cfg_attr(not(feature = "std"), feature(alloc))]
 #![deny(missing_docs)]
-#![doc(html_root_url = "https://docs.rs/throw/0.1.6")]
+#![doc(html_root_url = "https://docs.rs/throw/0.1.7")]
 //! Throw!
 //! ------
 //!
@@ -588,6 +588,20 @@ where
     }
 }
 
+#[cfg(feature = "std")]
+impl<E> std::error::Error for Error<E>
+where
+    E: std::error::Error
+{
+    fn description(&self) -> &str {
+        self.error().description()
+    }
+
+    fn cause(&self) -> Option<&std::error::Error> {
+        Some(self.error())
+    }
+}
+
 #[macro_export]
 macro_rules! up {
     ($e:expr) => (
