@@ -7,15 +7,20 @@ extern crate throw;
 use throw::Result;
 
 macro_rules! assert_matches {
-    ($expected:expr, $actual:expr) => ({
+    ($expected:expr, $actual:expr) => {{
         let expected = ($expected).replace("    ", "\t");
         let re = regex::Regex::new(&expected).expect("expected hardcoded regex to compile");
 
         let actual = format!("{}", $actual);
 
-        assert!(re.is_match(&actual),
-            format!("expected error to match regex `\n{}\n`, but found `\n{}\n`", expected, actual));
-    })
+        assert!(
+            re.is_match(&actual),
+            format!(
+                "expected error to match regex `\n{}\n`, but found `\n{}\n`",
+                expected, actual
+            )
+        );
+    }};
 }
 
 fn throw_static_message() -> Result<(), &'static str> {
@@ -72,6 +77,22 @@ fn throws_into() -> Result<(), String> {
     Ok(())
 }
 
+fn throws_into_key_value() -> Result<(), String> {
+    throw!(Err("some static string"), "key" => "value");
+    Ok(())
+}
+
+fn throws_into_multiple_key_value_pairs() -> Result<(), String> {
+    throw!(
+        Err("some static string"),
+        "key" => "value",
+        "key2" => "value2",
+        "key3" => "value3",
+        "key4" => "value4",
+    );
+    Ok(())
+}
+
 #[test]
 fn test_static_message() {
     let error = throw_static_message().unwrap_err();
@@ -89,7 +110,26 @@ fn test_static_message() {
 fn serialize_json() {
     let error = throw_with_context3().unwrap_err();
     let json = serde_json::to_string(&error).unwrap();
-    assert_eq!(r#"{"points":[{"line":40,"column":5,"module_path":"exceptions_work","file":"tests/exceptions_work.rs"},{"line":44,"column":5,"module_path":"exceptions_work","file":"tests/exceptions_work.rs"},{"line":49,"column":5,"module_path":"exceptions_work","file":"tests/exceptions_work.rs"}],"context":[{"key":"code","value":78},{"key":"application","value":"rust_core"},{"key":"project_secret","value":"omega"},{"key":"score","value":0.75},{"key":"height","value":948}],"error":"Error with context"}"#, json);
+    let whitespace_trim = regex::Regex::new("\\s+").unwrap();
+    let expected = r#"\{
+        "points":\[
+            \{"line":[0-9]+,"column":[0-9]+,"module_path":"exceptions_work",
+                "file":"tests/exceptions_work.rs"\},
+            \{"line":[0-9]+,"column":[0-9]+,"module_path":"exceptions_work",
+                "file":"tests/exceptions_work.rs"\},
+            \{"line":[0-9]+,"column":[0-9]+,"module_path":"exceptions_work",
+                "file":"tests/exceptions_work.rs"\}
+        \],
+        "context":\[
+            \{"key":"code","value":78\},
+            \{"key":"application","value":"rust_core"\},
+            \{"key":"project_secret","value":"omega"\},
+            \{"key":"score","value":0.75\},
+            \{"key":"height","value":948\}
+        \],
+        "error":"Error with context"
+    \}"#;
+    assert_matches!(whitespace_trim.replace_all(expected, "\\s*"), json);
 }
 
 #[test]
@@ -154,3 +194,28 @@ fn test_throws_into() {
         error
     )
 }
+
+#[test]
+fn test_throws_into_key_value() {
+    let error = throws_into_key_value().unwrap_err();
+    assert_matches!(
+        r#"Error: some static string
+    key: value
+    at [0-9]+:[0-9] in exceptions_work \([a-z/._-]+\)"#,
+        error
+    )
+}
+
+#[test]
+fn test_throws_into_multiple_key_value_pairs() {
+    let error = throws_into_multiple_key_value_pairs().unwrap_err();
+    assert_matches!(
+        r#"Error: some static string
+    key4: value4
+    key3: value3
+    key2: value2
+    key: value
+    at [0-9]+:[0-9] in exceptions_work \([a-z/._-]+\)"#,
+        error
+    )
+}
